/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: GetAllMBeansCommand.as 5199 2009-09-29 13:44:05Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.console.jmxbrowser.command {


import com.adobe.cairngorm.commands.ICommand;
import com.adobe.cairngorm.control.CairngormEvent;

import mx.controls.Alert;
import mx.rpc.IResponder;
import mx.rpc.events.FaultEvent;
import mx.rpc.events.ResultEvent;

import org.ow2.easybeans.console.jmxbrowser.business.IAllMBeansDelegate;
import org.ow2.easybeans.console.jmxbrowser.model.JMXBrowerModelLocator;

/**
 * Command used to get all MBeans available
 * @author Florent Benoit
 */
public class GetAllMBeansCommand implements ICommand, IResponder {


    /**
     * Execute the action by asking the loading of XML data of MBeans.
     */
    public function execute(event : CairngormEvent) : void {

        // Ask the delegate
        var delegate : IAllMBeansDelegate = JMXBrowerModelLocator.getInstance().getMBeansDelegate();
        delegate.responder = this;
        delegate.getAllMBeans();
    }

    /**
     * Manage the result found by a delegate.
     */
    public function result(event : Object) : void {
        // value is contained in the event
        var resultEvent : ResultEvent = event as ResultEvent;
        // cast
        var xml : XML = resultEvent.result as XML;

        // Gets the Model
        var model : JMXBrowerModelLocator = JMXBrowerModelLocator.getInstance();

        // Sets the XML value on the model
        model.xmlData = xml;
    }


    /**
     * Manage failure.
     */
    public function fault(event : Object) : void {
        var faultEvent : FaultEvent = FaultEvent(event);
        Alert.show("Error while fetching data !" + faultEvent);
    }

}
}

