/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: CallOperationMBeanEvent.as 5199 2009-09-29 13:44:05Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.console.jmxbrowser.event {

import com.adobe.cairngorm.control.CairngormEvent;

import org.ow2.easybeans.console.jmxbrowser.model.JMXBrowerModelLocator;
     

/**
 * Event used when calling an operation on an MBean.
 * @author Florent Benoit
 */
public class CallOperationMBeanEvent extends CairngormEvent {

    /**
     * MBean name
     */
    private var name : String;

    /**
     * Operation name
     */
    private var opName : String;

    /**
     * Parameters signature.
     */
    private var paramSig : Array;

    /**
     * Parameters value.
     */
    private var paramVal : Array;

    /**
     * Name of the Event.
     */
    public static const EVENT_CALL_OPERATION_MBEAN : String = "callOperationMBean" + JMXBrowerModelLocator.getInstance().componentID;

    /**
     * Default constructor.
     */
    public function CallOperationMBeanEvent(name : String, opName : String, paramSig : Array, paramVal : Array) {
        super(EVENT_CALL_OPERATION_MBEAN);
        this.name = name;
        this.opName = opName;
        this.paramSig = paramSig;
        this.paramVal = paramVal;
    }

    /**
     * Gets the name of the MBean on which set attribute.
     */
    public function get mBeanName() : String {
        return name;
    }

    /**
     * Gets the name of the MBean on which set attribute.
     */
    public function get operationName() : String {
        return opName;
    }

    /**
     * Gets the signatures of parameters
     */
    public function get parametersSignature() : Array {
        return paramSig;
    }

    /**
     * Gets the value of parameters
     */
    public function get parametersValue() : Array {
        return paramVal;
    }


}
}
