/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: EditAttributeRendererClass.as 5199 2009-09-29 13:44:05Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.console.jmxbrowser.view {

import mx.containers.HBox;
import mx.controls.Button;
import mx.controls.dataGridClasses.DataGridListData;
import mx.controls.listClasses.BaseListData;
import mx.managers.PopUpManager;

import org.ow2.easybeans.console.jmxbrowser.model.JMXBrowerModelLocator;
import org.ow2.easybeans.console.jmxbrowser.vo.JMXAttributeVO;

public class EditAttributeRendererClass extends HBox {

        /**
         * Model used for the JMX Browser.
         */
        [Bindable]
        public var model : JMXBrowerModelLocator = JMXBrowerModelLocator.getInstance();


        private var _listData:DataGridListData;

        [Bindable]
        public var jmxAttributes:JMXAttributeVO;

        [Bindable]
        private var editButton:Button;

        private var pop:EditAttributePopup;

        public function EditAttributeRendererClass() {
            super();
        }

        override public function set data(value:Object):void {
            super.data = value;
            // Keep the value as JMXAttributes
            this.jmxAttributes = value as JMXAttributeVO;
            // Update the edit button with the updated data
            update();
        }

        override public function get data():Object {
            return super.data;
        }

           public function get listData():BaseListData
        {
            return _listData;
        }

        public function set listData(value:BaseListData):void
        {
            _listData = DataGridListData(value);
        }

        // Adds the popup and set the JMXAttributes on it
        private function openPopup():void{
            pop= EditAttributePopup(PopUpManager.createPopUp(this.owner, EditAttributePopup, true));
            pop.jmxAttributes=this.jmxAttributes;
            pop.opener=this;
        }


        /**
         * Called when Tree selection is being changed.
         */
        public function clickButton(event:Event):void {

                callLater(openPopup);
        }



    private function update(): void {
        if (editButton == null) {
            return;
        }

        editButton.label = model.locale.getString("EDIT_ATTRIBUTE_RENDERER_EDIT_BUTTON_LABEL");

         if (jmxAttributes.isWritable) {
            editButton.visible = true;
         } else {
            editButton.visible = false;

         }
        if ('java.lang.String' == jmxAttributes.type
       || 'int' == jmxAttributes.type
       || 'long' == jmxAttributes.type
       || 'boolean' == jmxAttributes.type

       ) {
         editButton.enabled = true;
         editButton.toolTip = model.locale.getString("EDIT_ATTRIBUTE_RENDERER_EDIT_BUTTON_TOOLTIP");
    } else {
        // else disable button
        editButton.toolTip = model.locale.getString("EDIT_ATTRIBUTE_RENDERER_EDIT_BUTTON_DISABLED_TOOLTIP");
        editButton.enabled = false;
    }

}

         protected function creationComplete():void
  {
    editButton = new Button;
    editButton.label = model.locale.getString("EDIT_ATTRIBUTE_RENDERER_EDIT_BUTTON_LABEL");
    editButton.addEventListener("click",clickButton);
    editButton.setStyle("fontSize", 7);
    editButton.height = 14;
    editButton.toolTip = model.locale.getString("EDIT_ATTRIBUTE_RENDERER_EDIT_BUTTON_TOOLTIP");
    this.addChildAt(editButton, 0);

  }



    }
}
