/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: JMXBrowserClass.as 5199 2009-09-29 13:44:05Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.console.jmxbrowser.view {
import com.adobe.cairngorm.control.CairngormEventDispatcher;

import mx.containers.HBox;
import mx.controls.DataGrid;
import mx.controls.TextArea;
import mx.controls.Tree;
import mx.events.FlexEvent;
import mx.events.ListEvent;

import org.ow2.easybeans.console.jmxbrowser.event.GetAllMBeansEvent;
import org.ow2.easybeans.console.jmxbrowser.event.GetAttributesOfMBeanEvent;
import org.ow2.easybeans.console.jmxbrowser.event.GetOperationsOfMBeanEvent;
import org.ow2.easybeans.console.jmxbrowser.model.JMXBrowerModelLocator;


/**
 * Defines the parent class of the MXML component.
 * @author Florent Benoit
 */
public class JMXBrowserClass extends HBox {

    /**
     * Model used for the JMX Browser.
     */
    [Bindable]
    public var model : JMXBrowerModelLocator = JMXBrowerModelLocator.getInstance();


    /**
     * Tree that will display the JMX nodes.
     */
    [Bindable]
    public var jmxTree : Tree;



    [Bindable]
    // Component that will display the MBean attributes.
    public var dgAttributes : DataGrid;

    /**
     * Default constructor.
     */
    public function JMXBrowserClass() : void {
        addEventListener(FlexEvent.CREATION_COMPLETE, creationCompleteHandler);
    }


    /**
     * Handler called when object is created.
     */
    private function creationCompleteHandler(event : FlexEvent) : void {

        // when component is created, ask to fetch MBeans available.
        CairngormEventDispatcher.getInstance().dispatchEvent(new GetAllMBeansEvent());

    }

    /**
     * Called when Tree selection is being changed.
     */
    public function valueChanged(event : Event) : void {
    /*
       var resize:Resize = new Resize(selectedMBean);
       if (selectedMBean.text == "") {
       resize.heightTo = 0;
       } else {
       resize.heightTo = 40;

       }
       resize.play();
     */
    }


    public function setRelativeColWidths() : void {
        var globalWidth : int = dgAttributes.width - 55 - 90 - 30 - 30
        dgAttributes.columns[0].width = 55;
        dgAttributes.columns[1].width = 90;
        dgAttributes.columns[2].width = globalWidth - 50;
        dgAttributes.columns[3].width = 30;
        dgAttributes.columns[4].width = 30;
    }

    /**
     * Called when Tree selection is being changed.
     */
    public function treeChanged(event : Event) : void {

        // Event is an XML object
        var selectedNode : XML = event.target.selectedItem as XML;

        // Gets the model
        var model : JMXBrowerModelLocator = JMXBrowerModelLocator.getInstance();

        // Do something only if node selected is named "mbean"
        if (selectedNode != null && selectedNode.name() == "mbean") {

            // The node name is the MBean Name
            var mbeanName : String = selectedNode.toString();

            // Change the name of the selected MBean
            model.selectedMBeanName = mbeanName;

            // Requires the attributes of this MBean
            var getAttributesEvent : GetAttributesOfMBeanEvent = new GetAttributesOfMBeanEvent(mbeanName);
            CairngormEventDispatcher.getInstance().dispatchEvent(getAttributesEvent);

            // Requires the operations of this MBean
            var getOperationsEvent : GetOperationsOfMBeanEvent = new GetOperationsOfMBeanEvent(mbeanName);
            CairngormEventDispatcher.getInstance().dispatchEvent(getOperationsEvent);



        } else {
            // reset the values
            model.selectedMBeanName = "";
            model.selectedAttributes = null;
            model.selectedOperations = null;
        }
    }



}
}
