/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: OperationRendererClass.as 5199 2009-09-29 13:44:05Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.console.jmxbrowser.view {

import mx.collections.ArrayCollection;
import mx.containers.HBox;
import mx.controls.Text;
import mx.controls.dataGridClasses.DataGridListData;
import mx.controls.listClasses.BaseListData;

import org.ow2.easybeans.console.jmxbrowser.vo.JMXOperationVO;
import org.ow2.easybeans.console.jmxbrowser.vo.JMXParameterOperationVO;

[ResourceBundle("jmxbrowser")]
public class OperationRendererClass extends HBox {

    private var _listData : DataGridListData;

    [Bindable]
    public var jmxOperation : JMXOperationVO;


    public function OperationRendererClass() {
        super();
    }

    override public function set data(value : Object) : void {
        super.data = value;
        // Keep the value as JMX Operation
        this.jmxOperation = value as JMXOperationVO;

        // Update the text of the row with the given operation
        update();
    }

    override public function get data() : Object {
        return super.data;
    }

    public function get listData() : BaseListData {
        return _listData;
    }

    public function set listData(value : BaseListData) : void {
        _listData = DataGridListData(value);
    }


    private function update() : void {

        // first remove all children
        this.removeAllChildren();

        // Add return type
        var rType : Text = new Text();
        rType.text = jmxOperation.returnType;
        rType.toolTip = "Return type = " + jmxOperation.returnType;
        this.addChild(rType);

        // Add operation name
        var txt : Text = new Text();
        txt.text = jmxOperation.name + "(";

        // Add tooltip with the desc
        txt.toolTip = jmxOperation.desc;
        this.addChild(txt);


        // No parameter, ends here the method
        if (jmxOperation.parameters.length == 0) {
            txt.text += ")";
            return;
        }

        // Now, display the parameters
        var parameters : ArrayCollection = jmxOperation.parameters;

        var firstParam : Boolean = false;
        for each (var parameter : JMXParameterOperationVO in parameters) {
            var param : Text = new Text();
            // append a comma if not first parameter ?
            if (firstParam) {
                param.text = ", ";
            } else {
                firstParam = true;
            }
            // Add param name with its type
            param.text += parameter.name + ":" + parameter.type;
            param.toolTip = parameter.desc;
            this.addChild(param);

        }

        // Add the end of the method
        var txt2 : Text = new Text();
        txt2.text = ")";
        this.addChild(txt2);
    }
}
}
